@@ -13,11 +13,19 @@ __PACKAGE__->add_columns(
   'serial1' => {
     data_type => 'varchar',
     size => 100,
-    serializer_class => 'JSON'
+    serializer_class => 'JSON',
+    is_nullable => 1,
   },
   'serial2' => {
     data_type => 'varchar',
-    serializer_class => 'JSON'
+    serializer_class => 'JSON',
+    is_nullable => 1,
+  },
+  'serial3' => {
+    data_type => 'varchar',
+    serializer_class => 'JSON',
+    serializer_options => { allow_nonref => 1 },
+    is_nullable => 1,
   }
 );
 
